@@ -304,3 +304,12 @@ def Preview(request):
     :param request: Pyramid request object
     :rtype: Html snippet
     """
+
+
+def VocabularyFactory(context):
+    """ :class:`ptah.form.fields.VocabularyField` instantiate vocabulary
+    during field binding process.
+
+    :param context: Field context
+    :rtype: Vocabulary instance
+    """
